==> httraqt_1.2.0.orig.tar.gz: httraqt/sources/main/includes/ProgressTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2013 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef PROCESSTABULATOR_H
#define PROCESSTABULATOR_H

#include <QtGui>
#include <QtCore>
#include <QWidget>
#include <QString>
#include <QStandardItemModel>

#include "ui_ProgressTab.h"


class HTTraQt;

class ProgressTab: public QWidget, public Ui_ProgressTab
{
        Q_OBJECT
    public:
        ProgressTab(QWidget *parent = 0, Qt::WFlags fl = 0);
        void translate();
        void inProcessRefresh();

    private slots:
        void update();
        void cancelDwnload();

    protected:
        void resizeEvent(QResizeEvent *event);

    private:
        HTTraQt* parent;
        QVector<QPushButton*> cancelButtons;

};

#endif

==> httraqt_1.3.0.orig.tar.gz: httraqt/sources/main/includes/ProgressTab.h <==
/***************************************************************************
 * C++ Implementation:                                                     *
 * Copyright (C) 2012-2014 by Eduard Kalinowski                            *
 * Germany, Lower Saxony, Hanover                                          *
 * eduard_kalinowski@yahoo.de                                              *
 *                                                                         *
 * HTTraQt is free software; you can redistribute it and/or                *
 * modify it under the terms of the GNU Lesser General Public              *
 * License as published by the Free Software Foundation; either            *
 * version 3 of the License, or (at your option) any later version.        *
 *                                                                         *
 * HTTraQt is distributed in the hope that it will be useful, but          *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    *
 *                                                                         *
 * See the GNU Lesser General Public License for more details.             *
 *                                                                         *
 * You should have received a copy of the GNU Lesser General Public        *
 * License along with HTTraQt. If not, see  http://www.gnu.org/licenses    *
 ***************************************************************************/

#ifndef PROCESSTABULATOR_H
#define PROCESSTABULATOR_H

#include <QtGui>
#include <QtCore>
#include <QWidget>
#include <QString>
#include <QStandardItemModel>

#include "httraqt.h"
#include "ui_ProgressTab.h"


class HTTraQt;

class ProgressTab: public QWidget, public Ui_ProgressTab, public Translator
{
        Q_OBJECT
    public:
        ProgressTab(QWidget *parent = 0, Qt::WindowFlags fl = 0);
        void translateTab();
        void inProcessRefresh();

    private slots:
        void update();
        void cancelDwnload();

    protected:
        void resizeEvent(QResizeEvent *event);

    private:
        HTTraQt* parent;
        QVector<QPushButton*> cancelButtons;

};

#endif
